#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc
version:              2.19.2
visibility:           public
id:                   pandoc-2.19.2-K2E4RRwyISf72qO9Mw2GO8
key:                  pandoc-2.19.2-K2E4RRwyISf72qO9Mw2GO8
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML,
    RIS)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV and TSV tables)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, and plain text.
    It includes a powerful system for automatic citations
    and bibliographies, and it can be customized extensively
    using templates, filters, and custom readers and writers
    written in Lua.

category:             Text
abi:                  72918e539fad3faf9fb9616abd93bf07
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify
    Text.Pandoc.Citeproc Text.Pandoc.Class Text.Pandoc.Emoji
    Text.Pandoc.Error Text.Pandoc.Extensions Text.Pandoc.Filter
    Text.Pandoc.Highlighting Text.Pandoc.ImageSize Text.Pandoc.Logging
    Text.Pandoc.Lua Text.Pandoc.MIME Text.Pandoc.MediaBag
    Text.Pandoc.Options Text.Pandoc.PDF Text.Pandoc.Parsing
    Text.Pandoc.Process Text.Pandoc.Readers Text.Pandoc.Readers.BibTeX
    Text.Pandoc.Readers.CSV Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.Creole Text.Pandoc.Readers.CslJson
    Text.Pandoc.Readers.Custom Text.Pandoc.Readers.DocBook
    Text.Pandoc.Readers.Docx Text.Pandoc.Readers.DokuWiki
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.EndNote
    Text.Pandoc.Readers.FB2 Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.Ipynb
    Text.Pandoc.Readers.JATS Text.Pandoc.Readers.Jira
    Text.Pandoc.Readers.LaTeX Text.Pandoc.Readers.Man
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.MediaWiki
    Text.Pandoc.Readers.Muse Text.Pandoc.Readers.Native
    Text.Pandoc.Readers.OPML Text.Pandoc.Readers.Odt
    Text.Pandoc.Readers.Org Text.Pandoc.Readers.RIS
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.RTF
    Text.Pandoc.Readers.TWiki Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.TikiWiki Text.Pandoc.Readers.Txt2Tags
    Text.Pandoc.Readers.Vimwiki Text.Pandoc.SelfContained
    Text.Pandoc.Server Text.Pandoc.Shared Text.Pandoc.Sources
    Text.Pandoc.Templates Text.Pandoc.UTF8 Text.Pandoc.Writers
    Text.Pandoc.Writers.AnnotatedTable Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.BibTeX Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.CslJson
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.XWiki Text.Pandoc.Writers.ZimWiki
    Text.Pandoc.XML

hidden-modules:
    Text.Pandoc.App.CommandLineOptions Text.Pandoc.App.FormatHeuristics
    Text.Pandoc.App.Opt Text.Pandoc.App.OutputSettings
    Text.Pandoc.Class.CommonState Text.Pandoc.Class.IO
    Text.Pandoc.Class.PandocMonad Text.Pandoc.Class.PandocIO
    Text.Pandoc.Class.PandocPure Text.Pandoc.Class.Sandbox
    Text.Pandoc.Filter.Environment Text.Pandoc.Filter.JSON
    Text.Pandoc.Filter.Lua Text.Pandoc.Parsing.Capabilities
    Text.Pandoc.Parsing.Citations Text.Pandoc.Parsing.General
    Text.Pandoc.Parsing.GridTable Text.Pandoc.Parsing.Lists
    Text.Pandoc.Parsing.Math Text.Pandoc.Parsing.Smart
    Text.Pandoc.Parsing.State Text.Pandoc.Parsing.Types
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Fields Text.Pandoc.Readers.HTML.Parsing
    Text.Pandoc.Readers.HTML.Table
    Text.Pandoc.Readers.HTML.TagCategories
    Text.Pandoc.Readers.HTML.Types Text.Pandoc.Readers.LaTeX.Inline
    Text.Pandoc.Readers.LaTeX.Citation Text.Pandoc.Readers.LaTeX.Lang
    Text.Pandoc.Readers.LaTeX.Macro Text.Pandoc.Readers.LaTeX.Math
    Text.Pandoc.Readers.LaTeX.Parsing Text.Pandoc.Readers.LaTeX.SIunitx
    Text.Pandoc.Readers.LaTeX.Table Text.Pandoc.Readers.LaTeX.Types
    Text.Pandoc.Readers.Odt.Base Text.Pandoc.Readers.Odt.Namespaces
    Text.Pandoc.Readers.Odt.StyleReader
    Text.Pandoc.Readers.Odt.ContentReader
    Text.Pandoc.Readers.Odt.Generic.Fallible
    Text.Pandoc.Readers.Odt.Generic.SetMap
    Text.Pandoc.Readers.Odt.Generic.Utils
    Text.Pandoc.Readers.Odt.Generic.Namespaces
    Text.Pandoc.Readers.Odt.Generic.XMLConverter
    Text.Pandoc.Readers.Odt.Arrows.State
    Text.Pandoc.Readers.Odt.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Docx.Table Text.Pandoc.Writers.Docx.Types
    Text.Pandoc.Writers.GridTable Text.Pandoc.Writers.JATS.References
    Text.Pandoc.Writers.JATS.Table Text.Pandoc.Writers.JATS.Types
    Text.Pandoc.Writers.LaTeX.Caption Text.Pandoc.Writers.LaTeX.Notes
    Text.Pandoc.Writers.LaTeX.Table Text.Pandoc.Writers.LaTeX.Lang
    Text.Pandoc.Writers.LaTeX.Types Text.Pandoc.Writers.LaTeX.Citation
    Text.Pandoc.Writers.LaTeX.Util Text.Pandoc.Writers.Markdown.Table
    Text.Pandoc.Writers.Markdown.Types
    Text.Pandoc.Writers.Markdown.Inline Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Blaze
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output
    Text.Pandoc.Lua.ErrorConversion Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Orphans Text.Pandoc.Lua.PandocLua
    Text.Pandoc.Lua.Writer.Classic Text.Pandoc.XML.Light
    Text.Pandoc.XML.Light.Types Text.Pandoc.XML.Light.Proc
    Text.Pandoc.XML.Light.Output Text.Pandoc.Network.HTTP
    Text.Pandoc.CSS Text.Pandoc.CSV Text.Pandoc.RoffChar
    Text.Pandoc.UUID Text.Pandoc.Translations Text.Pandoc.Slides
    Text.Pandoc.Image Text.Pandoc.Citeproc.BibTeX
    Text.Pandoc.Citeproc.CslJson Text.Pandoc.Citeproc.Data
    Text.Pandoc.Citeproc.Locator Text.Pandoc.Citeproc.MetaValue
    Text.Pandoc.Citeproc.Util Paths_pandoc

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-2.19.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-2.19.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc
hs-libraries:         HSpandoc-2.19.2-K2E4RRwyISf72qO9Mw2GO8
depends:
    Glob-0.10.2-KOLQS0coC5A6YlxLhI3G2b
    JuicyPixels-3.3.8-JChQQ46XOu31YkK34mHFAN
    SHA-1.6.4.4-1UNVNO3JXJdDGqRoMkntZx
    aeson-2.1.1.0-8KPen6hyeogLmhemp4ZbOa
    aeson-pretty-0.8.9-HgDgW0QkNCrJG86cGxB5yu array-0.5.4.0
    attoparsec-0.14.4-1cvWowE4NeVTtjhbiJiE3 base-4.15.1.0
    base64-0.4.2.4-6UyNQydv5thJga7IOkafBq binary-0.8.8.0
    blaze-html-0.9.1.2-D7HS2RFjvZl1edcolkQH6T
    blaze-markup-0.8.2.8-760Vp6lhnYkBvV5Dqo18Vo bytestring-0.10.12.1
    case-insensitive-1.2.1.0-Krzwt9Uo3qoLEdElVbDu5x
    citeproc-0.8.0.2-81r8lTYMq6Q7iRcSL72S0d
    commonmark-0.2.2-EFCJQz4ORcl4OBC9WHk5V7
    commonmark-extensions-0.2.3.3-63VWZXR1mUJGXwCeFCgUGF
    commonmark-pandoc-0.2.1.2-3uOLDWpt9n511dV4UjQ1G5
    connection-0.3.1-HjVX2WfaB8Z3WaHWkhce18 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW deepseq-1.4.5.0
    directory-1.3.6.2 doclayout-0.4-3ZpE2KuLmRUBJPTH718IsP
    doctemplates-0.10.0.2-8vZ1iIIt72OJkzSWippNho
    emojis-0.1.2-L1cgRRz1r836fLqubUKaVD exceptions-0.10.4
    file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn filepath-1.4.2.1
    gridtables-0.1.0.0-Lp22Uwt7xm0Hx0YrJRYJMV
    haddock-library-1.10.0-1znuaufLb6bCmrBHxvK8hK
    hslua-2.2.1-69AmB8946ii4BlrgglzcK6
    hslua-aeson-2.2.1-1bISormrHNCqFaZ6qhmhk
    hslua-module-doclayout-1.0.4-L6CI4KgOq25KDxjzpwtQxs
    hslua-module-path-1.0.3-Fz21NMUYtY2LTpUacscLxn
    hslua-module-system-1.0.2-5UqA540PoOPBLtHB1z4xr8
    hslua-module-text-1.0.2-AuUVN8N3iwQBkaiRa1Ktl6
    hslua-module-version-1.0.3-AGnAsJSJMKiExTCg0uQ62z
    http-client-0.7.13.1-9tRWrSzuUWQEzDuKMcuxcd
    http-client-tls-0.3.6.1-9Ni1ia9IAbb4Di3xoK5YTY
    http-types-0.12.3-JAMRNTQTYKZAFFy6KP2C7i
    ipynb-0.2-AA333rskhTBBkLyIKWisWO
    jira-wiki-markup-1.4.0-21JjBaMXhbO1bk0KtiO3d0
    lpeg-1.0.3-H6GlrR84sJQBVYbBpsz3C9 mtl-2.2.2
    network-3.1.2.7-CYWaC4XvHgd3jC4vMNSEt4
    network-uri-2.6.4.2-Bqno6giiEJ72xMDyBU05Tf
    pandoc-lua-marshal-0.1.7-GgeZO0sk6MgE7bqoWgDiR3
    pandoc-types-1.22.2.1-K1L9sslOQzFGE2RSR6ZaRy parsec-3.1.14.0
    pretty-1.1.3.6 pretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR
    process-1.6.13.2 random-1.2.1.1-AHzwveRxxoAAsQlVBjR4re
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    scientific-0.3.7.0-4jDy2Qi3SPf6ae03s0nfwm
    servant-server-0.19.2-HoM2k8wkJ4JEroavrWGlL3
    skylighting-0.13.1.2-82PsWXnFvcPKqZIDRkyFzs
    skylighting-core-0.13.1.2-LPneHnvAZhRAJM9VkVX8pV
    split-0.2.3.5-D1U8q4vlNdk5QDry85lN6
    syb-0.7.2.2-KYctT8xvO452aGvebEW3ui
    tagsoup-0.14.8-DzGiPfykZSz5mreMlNQlbO
    temporary-1.3-43mWfHcWlQaIZH67QuZuiK
    texmath-0.12.5.4-8XYIJKsbMKD8aFj2ua6HFz text-1.2.5.0
    text-conversions-0.3.1.1-4YjYjXj1tNT2hCrOhyUHPN time-1.9.3
    unicode-collation-0.1.3.3-Fvlj5tlgjbmA0W6vtjkOwx
    unicode-transforms-0.4.0.1-KaxYtzCCRGl1oiLP1k4NKc unix-2.7.2.2
    wai-3.2.3-6OBZnfym3XnEpgdZxbCyP2 xml-1.3.14-6hlhhPBptprHwK7nsE7OzM
    xml-conduit-1.9.1.1-9isUTPkINkeFjtZ8ZnUjP0
    xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu
    yaml-0.11.8.0-CPn6zky2aVy5KxtIEbRscK
    zip-archive-0.4.2.2-69U1eYznBgiJZszgTmTsGc
    zlib-0.6.3.0-1sTZptDDS7NHMKV41PsJoe

haddock-interfaces:   /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

